CKEDITOR.plugins.setLang("docprops","ku",{bgColor:"ڕەنگی پاشبنەما",bgFixed:"بێ هاتووچوپێکردنی (چەسپاو) پاشبنەمای وێنه",bgImage:"ناونیشانی بەستەری وێنەی پاشبنەما",charset:"دەستەی نووسەی بەکۆدکەر",charsetASCII:"ASCII",charsetCE:"ناوەڕاستی ئەوروپا",charsetCR:"سیریلیك",charsetCT:"چینی(Big5)",charsetGR:"یۆنانی",charsetJP:"ژاپۆنی",charsetKR:"کۆریا",charsetOther:"دەستەی نووسەی بەکۆدکەری تر",charsetTR:"تورکی",charsetUN:"Unicode (UTF-8)",charsetWE:"ڕۆژئاوای ئەوروپا",chooseColor:"هەڵبژێرە",design:"شێوەکار",
docTitle:"سەردێڕی پەڕه",docType:"سەرپەڕەی جۆری پەڕه",docTypeOther:"سەرپەڕەی جۆری پەڕەی تر",label:"خاسییەتی پەڕه",margin:"تەنیشت پەڕه",marginBottom:"ژێرەوه",marginLeft:"چەپ",marginRight:"ڕاست",marginTop:"سەرەوه",meta:"زانیاری مێتا",metaAuthor:"نووسەر",metaCopyright:"مافی بڵاوکردنەوەی",metaDescription:"پێناسەی لاپەڕه",metaKeywords:"بەڵگەنامەی وشەی کاریگەر(به کۆما لێکیان جیابکەوه)",other:"هیتر...",previewHtml:'<p>ئەمە وەك نموونەی <strong>دەقه</strong>. تۆ بەکاردەهێنیت <a href="javascript:void(0)">CKEditor</a>.</p>',
title:"خاسییەتی پەڕه",txtColor:"ڕەنگی دەق",xhtmlDec:"بەیاننامەکانی XHTML لەگەڵدابێت"});